.. kolla documentation master file, created by
   sphinx-quickstart on Tue Aug  6 14:08:15 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Kolla-cli Release Notes documentation
================================================

.. toctree::
   :maxdepth: 2

   unreleased
   train


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
